summaryrefslogtreecommitdiffstats
path: root/kdesktop/lock
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2018-11-28 23:51:20 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2018-11-28 23:51:20 +0900
commit6db0c5f228d12fc1a1ef861717d1dc4a3c9d6a6c (patch)
tree972d106294d740e92c586300da66d011bfe9d13e /kdesktop/lock
parent6ae10fc66ed3c35e98e49bac8bf6670f0a9e2d6b (diff)
downloadtdebase-6db0c5f228d12fc1a1ef861717d1dc4a3c9d6a6c.tar.gz
tdebase-6db0c5f228d12fc1a1ef861717d1dc4a3c9d6a6c.zip
Improved previous commit using local8Bit() in place of utf8() when a
password is transmitted over pipes to other processes. Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
Diffstat (limited to 'kdesktop/lock')
-rw-r--r--kdesktop/lock/lockprocess.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesktop/lock/lockprocess.cc b/kdesktop/lock/lockprocess.cc
index b34c5b494..fdde3fc9e 100644
--- a/kdesktop/lock/lockprocess.cc
+++ b/kdesktop/lock/lockprocess.cc
@@ -2807,8 +2807,8 @@ void LockProcess::processInputPipeCommand(TQString inputcommand) {
pin_entry = qryDlg.getEntry();
mInfoMessageDisplayed=false;
if (mPipeOpen_out == true) {
- TQCString pin_entry_utf8 = pin_entry.utf8(); // utf8 length may differ from TQString length
- if (write(mPipe_fd_out, pin_entry_utf8.data(), pin_entry_utf8.length()+1) == -1) {
+ TQCString pin_entry_local8 = pin_entry.local8Bit(); // local 8 bit length may differ from TQString length
+ if (write(mPipe_fd_out, pin_entry_local8.data(), pin_entry_local8.length()+1) == -1) {
// Error handler to shut up gcc warnings
}
if (write(mPipe_fd_out, "\n\r", 3) == -1) {